@@ -37,8 +37,8 @@ In order to read the file, create a new proxy with:
 ar = arpy.Archive('some_ar_file')
 ar.read_all_headers()
 
-The list of files can be listed through:
-ar.archived_files.values()
+The list of file names can be listed through:
+ar.archived_files.keys()
 
 Files themselves can be opened by getting the value of:
 f = ar.archived_files['filename']
@@ -57,6 +57,7 @@ HEADER_NORMAL = 5
 HEADER_TYPES = {
 		HEADER_BSD: 'BSD',
 		HEADER_GNU: 'GNU', HEADER_GNU_TABLE: 'GNU_TABLE',
+		HEADER_GNU_SYMBOLS: 'GNU_SYMBOLS',
 		HEADER_NORMAL: 'NORMAL'}
 
 GLOBAL_HEADER_LEN = 8
@@ -95,7 +96,7 @@ class ArchiveFileHeader(object):
 		try:
 			self.size = int(size)
 
-			if self.type in (HEADER_NORMAL, HEADER_BSD):
+			if self.type in (HEADER_NORMAL, HEADER_BSD, HEADER_GNU):
 				self.timestamp = int(timestamp)
 				self.uid = int(uid)
 				self.gid = int(gid)
@@ -106,8 +107,12 @@ class ArchiveFileHeader(object):
 					"cannot convert file header fields to integers", err)
 
 		self.offset = offset
+		name = name.rstrip()
+		if len(name) > 1:
+			name = name.rstrip('/')
+
 		if self.type == HEADER_NORMAL:
-			self.name = name.rstrip()
+			self.name = name
 			self.file_offset = offset + HEADER_LEN
 		else:
 			self.name = None
@@ -121,7 +126,7 @@ class ArchiveFileHeader(object):
 					HEADER_TYPES[self.type], self.size)
 		else:
 			return '''<ArchiveFileHeader: "%s" type:%s>''' % (self.name,
-					HEADER_TYPES[self.type])
+					HEADER_TYPES.get(self.type, "unknown %i" % (self.type,)))
 
 class ArchiveFileData(object):
 	""" File-like object used for reading an archived file """
@@ -174,7 +179,7 @@ class Archive(object):
 	def __init__(self, filename):
 		self.headers = []
 		self.filename = filename
-		self.file = open(self.filename, "r")
+		self.file = open(self.filename, "rb")
 		if self.file.read(GLOBAL_HEADER_LEN) != "!<arch>\n":
 			raise ArchiveFormatError("file is missing the global header")
 		
@@ -245,10 +250,10 @@ class Archive(object):
 			if gnu_position not in self.gnu_table:
 				raise ArchiveFormatError("file references a name not present in the index")
 			header.name = self.gnu_table[gnu_position]
-			if not header.name.endswith('/'):
-				raise ArchiveFormatError("GNU filename not ending with a '/'")
-			header.name = header.name[:-1]
 			
+		elif header.type == HEADER_GNU_SYMBOLS:
+			pass
+
 		else:
 			raise NotImplementedError("strange header, not implemented yet")
 		
